package combinat

  1. Overview
  2. Docs

Module CombinatSource

Compute the partitions of an integer n into m parts. See (Knuth 3b, pg. 2).

Compute the partitions of an integer n into m parts, including partitions where some elements are zero.

Compute the unique permutations of an array. See (Knuth 2b, pg. 1).

Compute all of the t combinations of the numbers in 0, {i n}.